# JARVIS Downloader
#### Hi there Users! I am glad that you are here!

## Built with

<code><img height="30" src="https://raw.githubusercontent.com/github/explore/80688e429a7d4ef2fca1e82350fe8e3517d3494d/topics/python/python.png"></code>

## About this project:-
#### This is JARVIS Downloader, A downloader for [JARVIS](https://www.github.com/Hashah2311/JARVIS). It is completely based on python.

## Installation
#### As this is a python package so you can do ```pip install JARVIS_Downloader```, but you can also find .whl package in [packages section](https://github.com/users/Hashah2311/packages?repo_name=JARVIS_Downloader) and a portable version in [releases section](https://github.com/Hashah2311/JARVIS_Downloader/releases)
#### You dont need to install python to run portable version of this app.

## Code Structure


    ├── dist
    ├── JARVIS_Downloader
    ├── pyproject.toml
    ├── setup.cfg
    ├── README.md
    ├── LICENSE.md
    └── .gitattributes

## Extras
#### If you have any issues, you can post it in the issues page and I will try to solve it ASAP. If you are interested to know more about the code,etc. you can mail me on "shahharshit063@gmail.com".